@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -19,12 +19,12 @@
 #define ZBX_STR(str)	ZBX_STR2(str)
 
 #define APPLICATION_NAME	"Zabbix Agent"
-#define ZABBIX_REVDATE		"11 February 2026"
+#define ZABBIX_REVDATE		"23 April 2025"
 #define ZABBIX_VERSION_MAJOR	7
-#define ZABBIX_VERSION_MINOR	0
-#define ZABBIX_VERSION_PATCH	23
+#define ZABBIX_VERSION_MINOR	2
+#define ZABBIX_VERSION_PATCH	6
 #ifndef ZABBIX_VERSION_REVISION
-#	define ZABBIX_VERSION_REVISION	f4175e9b3ce
+#	define ZABBIX_VERSION_REVISION	9e15a0eb7a0
 #endif
 #ifdef _WINDOWS
 #	ifndef ZABBIX_VERSION_RC_NUM
