@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -21,16 +21,15 @@ import (
 	"strings"
 )
 
-//nolint:revive // these consts are part of higher level script
 const (
-	ZABBIX_REVDATE          = "11 February 2026"
+	ZABBIX_REVDATE          = "23 April 2025"
 	ZABBIX_VERSION_MAJOR    = 7
-	ZABBIX_VERSION_MINOR    = 0
-	ZABBIX_VERSION_PATCH    = 23
+	ZABBIX_VERSION_MINOR    = 2
+	ZABBIX_VERSION_PATCH    = 6
 	ZABBIX_VERSION_RC       = ""
 	ZABBIX_VERSION_RC_NUM   = "1400"
-	ZABBIX_VERSION_REVISION = "f4175e9b3ce"
-	copyrightMessage        = "Copyright (C) 2026 Zabbix SIA\n" +
+	ZABBIX_VERSION_REVISION = "9e15a0eb7a0"
+	copyrightMessage        = "Copyright (C) 2025 Zabbix SIA\n" +
 		"License AGPLv3: GNU Affero General Public License version 3 <https://www.gnu.org/licenses/>.\n" +
 		"This is free software: you are free to change and redistribute it according to\n" +
 		"the license. There is NO WARRANTY, to the extent permitted by law."
