@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -16,18 +16,19 @@
 #include "dbsync.h"
 #include "dbconfig.h"
 
-#include "zbxdbhigh.h"
+#include "zbxdb.h"
 #include "zbxjson.h"
 #include "zbxvault.h"
 #include "zbxstr.h"
 #include "zbxexpr.h"
 #include "zbxregexp.h"
 #include "zbxnum.h"
+#include "zbx_expression_constants.h"
 
 ZBX_PTR_VECTOR_IMPL(um_macro, zbx_um_macro_t *)
 ZBX_PTR_VECTOR_IMPL(um_host, zbx_um_host_t *)
 
-#define ZBX_MACRO_NO_KVS_VALUE	"*UNKNOWN*"
+#define ZBX_MACRO_NO_KVS_VALUE	STR_UNKNOWN_VARIABLE
 
 typedef enum
 {
@@ -56,13 +57,6 @@ static zbx_um_cache_t	*um_cache_dup(zbx_um_cache_t *cache)
 
 	dup = (zbx_um_cache_t *)dbconfig_shmem_malloc_func(NULL, sizeof(zbx_um_cache_t));
 	dup->refcount = 1;
-	memset(&dup->hosts, 0, sizeof(dup->hosts));
-
-	if (0 != get_dc_config()->um_hosts.num_slots)
-	{
-		dup->hosts = get_dc_config()->um_hosts;
-		memset(&get_dc_config()->um_hosts, 0 , sizeof(get_dc_config()->um_hosts));
-	}
 
 	zbx_hashset_copy(&dup->hosts, &cache->hosts, sizeof(zbx_um_host_t *));
 	zbx_hashset_iter_reset(&dup->hosts, &iter);
@@ -200,11 +194,7 @@ void	um_cache_release(zbx_um_cache_t *cache)
 	zbx_hashset_iter_reset(&cache->hosts, &iter);
 	while (NULL != (host = (zbx_um_host_t **)zbx_hashset_iter_next(&iter)))
 		um_host_release(*host);
-
-	if (0 == get_dc_config()->um_hosts.num_slots)
-		get_dc_config()->um_hosts = cache->hosts;
-	else
-		zbx_hashset_destroy(&cache->hosts);
+	zbx_hashset_destroy(&cache->hosts);
 
 	dbconfig_shmem_free_func(cache);
 }
@@ -867,7 +857,7 @@ static void	um_cache_sync_hosts(zbx_um_cache_t *cache, zbx_dbsync_t *sync)
  *********************************************************************************/
 zbx_um_cache_t	*um_cache_sync(zbx_um_cache_t *cache, zbx_uint64_t revision, zbx_dbsync_t *gmacros,
 		zbx_dbsync_t *hmacros, zbx_dbsync_t *htmpls, const zbx_config_vault_t *config_vault,
-		double *um_cache_dup_sec, zbx_int64_t *um_cache_dup_size, unsigned char program_type)
+		unsigned char program_type)
 {
 	if (ZBX_DBSYNC_INIT != gmacros->mode && ZBX_DBSYNC_INIT != hmacros->mode && ZBX_DBSYNC_INIT != htmpls->mode &&
 			0 == gmacros->rows.values_num && 0 == hmacros->rows.values_num && 0 == htmpls->rows.values_num)
@@ -877,14 +867,8 @@ zbx_um_cache_t	*um_cache_sync(zbx_um_cache_t *cache, zbx_uint64_t revision, zbx_
 
 	if (SUCCEED == um_cache_is_locked(cache))
 	{
-		double		sec = zbx_time();
-		zbx_int64_t	used_size = dbconfig_used_size();
-
 		um_cache_release(cache);
 		cache = um_cache_dup(cache);
-
-		*um_cache_dup_sec = zbx_time() - sec;
-		*um_cache_dup_size = dbconfig_used_size() - used_size;
 	}
 
 	cache->revision = revision;
@@ -1019,11 +1003,7 @@ static int	um_cache_get_host_macro(const zbx_um_cache_t *cache, const zbx_uint64
 	}
 
 	if (0 != templateids.values_num)
-	{
-		/* Sort templates by id so the import order precedences over the linking order. */
-		zbx_vector_uint64_sort(&templateids, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
 		ret = um_cache_get_host_macro(cache, templateids.values, templateids.values_num, name, context, macro);
-	}
 	else
 		ret = FAIL;
 out:
@@ -1098,7 +1078,7 @@ void	um_cache_resolve_const(const zbx_um_cache_t *cache, const zbx_uint64_t *hos
 	if (NULL != um_macro)
 	{
 		if (ZBX_MACRO_ENV_NONSECURE == env && ZBX_MACRO_VALUE_TEXT != um_macro->type)
-			*value = ZBX_SECRET_MASK;
+			*value = ZBX_MACRO_SECRET_MASK;
 		else
 			*value = (NULL != um_macro->value ? um_macro->value : ZBX_MACRO_NO_KVS_VALUE);
 	}
@@ -1131,7 +1111,7 @@ void	um_cache_resolve(const zbx_um_cache_t *cache, const zbx_uint64_t *hostids,
 	if (NULL != um_macro)
 	{
 		if (ZBX_MACRO_ENV_NONSECURE == env && ZBX_MACRO_VALUE_TEXT != um_macro->type)
-			*value = zbx_strdup(*value, ZBX_SECRET_MASK);
+			*value = zbx_strdup(*value, ZBX_MACRO_SECRET_MASK);
 		else
 			*value = zbx_strdup(NULL, (NULL != um_macro->value ? um_macro->value : ZBX_MACRO_NO_KVS_VALUE));
 	}
@@ -1145,7 +1125,7 @@ void	um_cache_resolve(const zbx_um_cache_t *cache, const zbx_uint64_t *hostids,
 			if (ZBX_MACRO_VALUE_TEXT == um_macro->type)
 				out = um_macro->value;
 			else
-				out = (NULL != um_macro->value ? ZBX_SECRET_MASK : ZBX_MACRO_NO_KVS_VALUE);
+				out = (NULL == um_macro->value ? ZBX_MACRO_SECRET_MASK : ZBX_MACRO_NO_KVS_VALUE);
 		}
 
 		zabbix_log(LOG_LEVEL_DEBUG, "End of %s(): %s", __func__, ZBX_NULL2EMPTY_STR(out));
@@ -1252,7 +1232,7 @@ void	um_cache_dump(zbx_um_cache_t *cache)
 			{
 				case ZBX_MACRO_VALUE_SECRET:
 				case ZBX_MACRO_VALUE_VAULT:
-					value = ZBX_SECRET_MASK;
+					value = ZBX_MACRO_SECRET_MASK;
 					break;
 				default:
 					value = macro->value;
@@ -1366,44 +1346,6 @@ void	um_cache_get_macro_updates(const zbx_um_cache_t *cache, const zbx_uint64_t
 	zbx_vector_um_host_destroy(&hosts);
 }
 
-/*********************************************************************************
- *                                                                               *
- * Purpose: check if there are any macro updates for the specified hosts since   *
- *          the given revision                                                   *
- *                                                                               *
- * Parameters: cache       - [IN] user macro cache                               *
- *             hostids     - [IN] identifiers of the hosts to check              *
- *             hostids_num - [IN] number of hosts to check                       *
- *             revision    - [IN]                                                *
- *                                                                               *
- * Return value: SUCCEED - at least one host has updates since the revision      *
- *               FAIL    - no updates found                                      *
- *                                                                               *
- *********************************************************************************/
-int	um_cache_check_macro_updates(const zbx_um_cache_t *cache, const zbx_uint64_t *hostids, int hostids_num,
-		zbx_uint64_t revision)
-{
-	int			ret = SUCCEED;
-	zbx_vector_um_host_t	hosts;
-
-	zbx_vector_um_host_create(&hosts);
-
-	for (int i = 0; i < hostids_num; i++)
-	{
-		um_cache_get_hosts(cache, &hostids[i], revision, &hosts);
-
-		if (0 != hosts.values_num)
-			goto out;
-	}
-
-	ret = FAIL;
-out:
-	zbx_vector_um_host_destroy(&hosts);
-
-	return ret;
-}
-
-
 /*********************************************************************************
  *                                                                               *
  * Purpose: recursively remove templates linked to the hostid from unused_hosts  *
