@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -16,11 +16,11 @@
 
 #include "zbxjson.h"
 #include "zbxcacheconfig.h"
-#include "zbxsysinfo.h"
 #include "zbxcomms.h"
-#include "zbxtypes.h"
-#include <stddef.h>
 #include "zbxagentget.h"
+#include "zbxversion.h"
+
+#include <stddef.h>
 
 /******************************************************************************
  *                                                                            *
@@ -127,7 +127,7 @@ int	zbx_agent_get_value(const zbx_dc_item_t *item, const char *config_source_ip,
 			ret = TIMEOUT_ERROR;
 		}
 		else
-			ret = GATEWAY_ERROR;
+			ret = NETWORK_ERROR;
 
 		zbx_json_free(&j);
 	}
