@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -83,13 +83,8 @@ static void	zbx_db_mock_field_init(zbx_db_mock_field_t *field, int field_type, i
 	switch (field_type)
 	{
 		case ZBX_TYPE_CHAR:
-#if defined(HAVE_ORACLE)
-			field->chars_num = field_len;
-			field->bytes_num = 4000;
-#else
 			field->chars_num = field_len;
 			field->bytes_num = -1;
-#endif
 			return;
 	}
 
@@ -150,10 +145,9 @@ static int	zbx_db_mock_field_append(zbx_db_mock_field_t *field, const char *text
  *           larger than ZBX_PP_VALUE_PREVIEW_LEN characters.                 *
  *                                                                            *
  ******************************************************************************/
-static char	*pp_error_format_value(const zbx_variant_t *value)
+static void	pp_error_format_value(const zbx_variant_t *value, char **value_str)
 {
 	const char	*value_desc;
-	char		*value_str;
 	size_t		i, len;
 
 #define ZBX_PP_VALUE_PREVIEW_LEN	100
@@ -164,24 +158,23 @@ static char	*pp_error_format_value(const zbx_variant_t *value)
 	{
 		/* truncate value and append '...' */
 		len = zbx_strlen_utf8_nchars(value_desc, ZBX_PP_VALUE_PREVIEW_LEN - ZBX_CONST_STRLEN("..."));
-		value_str = zbx_malloc(NULL, len + ZBX_CONST_STRLEN("...") + 1);
-		memcpy(value_str, value_desc, len);
-		memcpy(value_str + len, "...", ZBX_CONST_STRLEN("...") + 1);
+		*value_str = zbx_malloc(NULL, len + ZBX_CONST_STRLEN("...") + 1);
+		memcpy(*value_str, value_desc, len);
+		memcpy(*value_str + len, "...", ZBX_CONST_STRLEN("...") + 1);
 	}
 	else
 	{
-		value_str = zbx_malloc(NULL, (len = strlen(value_desc)) + 1);
-		memcpy(value_str, value_desc, len + 1);
+		*value_str = zbx_malloc(NULL, (len = strlen(value_desc)) + 1);
+		memcpy(*value_str, value_desc, len + 1);
 	}
 
 	/* replace control characters */
 	for (i = 0; i < len; i++)
 	{
-		if (0 != iscntrl(value_str[i]))
-			value_str[i] = '.';
+		if (0 != iscntrl((*value_str)[i]))
+			(*value_str)[i] = '.';
 	}
 
-	return value_str;
 #undef ZBX_PP_VALUE_PREVIEW_LEN
 }
 
@@ -194,27 +187,23 @@ static char	*pp_error_format_value(const zbx_variant_t *value)
  *             out    - [OUT] formatted string                                *
  *                                                                            *
  ******************************************************************************/
-static char	*pp_error_format_result(int step, const zbx_pp_result_t *result)
+static void	pp_error_format_result(int step, const zbx_pp_result_t *result, char **out)
 {
-	char	*actions[] = {"", " (discard value)", " (set value)", " (set error)"}, *error = NULL;
-	size_t	error_alloc = 0, error_offset = 0;
+	char	*actions[] = {"", " (discard value)", " (set value)", " (set error)"};
 
 	if (ZBX_VARIANT_ERR != result->value.type)
 	{
 		char	*value_str;
 
-		value_str = pp_error_format_value(&result->value);
-		zbx_snprintf_alloc(&error, &error_alloc, &error_offset, "%d. Result%s: %s\n", step,
-				actions[result->action], value_str);
+		pp_error_format_value(&result->value, &value_str);
+		*out = zbx_dsprintf(NULL, "%d. Result%s: %s\n", step, actions[result->action], value_str);
 		zbx_free(value_str);
 	}
 	else
 	{
-		zbx_snprintf_alloc(&error, &error_alloc, &error_offset, "%d. Failed%s: %s\n", step,
-			actions[result->action], zbx_variant_value_desc(&result->value));
+		*out = zbx_dsprintf(NULL, "%d. Failed%s: %s\n", step, actions[result->action],
+				zbx_variant_value_desc(&result->value));
 	}
-
-	return error;
 }
 
 /******************************************************************************
@@ -229,17 +218,17 @@ static char	*pp_error_format_result(int step, const zbx_pp_result_t *result)
  ******************************************************************************/
 void	pp_format_error(const zbx_variant_t *value, zbx_pp_result_t *results, int results_num, char **error)
 {
-	char			*value_str, *err_step = NULL;
+	char			*value_str, *err_step;
 	int			i;
-	size_t			error_alloc = 0, error_offset = 0;
+	size_t			error_alloc = 512, error_offset = 0;
 	zbx_vector_str_t	results_str;
 	zbx_db_mock_field_t	field;
 
 	zbx_vector_str_create(&results_str);
-	zbx_vector_str_reserve(&results_str, 3);
 
 	/* add header to error message */
-	value_str = pp_error_format_value(value);
+	*error = zbx_malloc(NULL, error_alloc);
+	pp_error_format_value(value, &value_str);
 	zbx_snprintf_alloc(error, &error_alloc, &error_offset, "Preprocessing failed for: %s\n", value_str);
 	zbx_free(value_str);
 
@@ -249,7 +238,7 @@ void	pp_format_error(const zbx_variant_t *value, zbx_pp_result_t *results, int r
 	zbx_db_mock_field_append(&field, "...\n");
 
 	/* format the last (failed) step */
-	err_step = pp_error_format_result(results_num, &results[results_num - 1]);
+	pp_error_format_result(results_num, &results[results_num - 1], &err_step);
 	zbx_vector_str_append(&results_str, err_step);
 
 	if (SUCCEED == zbx_db_mock_field_append(&field, err_step))
@@ -257,7 +246,7 @@ void	pp_format_error(const zbx_variant_t *value, zbx_pp_result_t *results, int r
 		/* format the first steps */
 		for (i = results_num - 2; i >= 0; i--)
 		{
-			err_step = pp_error_format_result(i + 1, &results[i]);
+			pp_error_format_result(i + 1, &results[i], &err_step);
 
 			if (SUCCEED != zbx_db_mock_field_append(&field, err_step))
 			{
@@ -313,7 +302,7 @@ int	pp_error_on_fail(zbx_dc_um_shared_handle_t *um_handle, zbx_uint64_t hostid,
 	switch (step->error_handler)
 	{
 		case ZBX_PREPROC_FAIL_DISCARD_VALUE:
-			zbx_variant_clear_ext(value, ZBX_VARIANT_FLAG_CHANGED);
+			zbx_variant_clear(value);
 			break;
 		case ZBX_PREPROC_FAIL_SET_VALUE:
 		case ZBX_PREPROC_FAIL_SET_ERROR:
@@ -322,8 +311,15 @@ int	pp_error_on_fail(zbx_dc_um_shared_handle_t *um_handle, zbx_uint64_t hostid,
 
 			if (NULL != um_handle)
 			{
-				zbx_dc_expand_user_and_func_macros_from_cache(um_handle->um_cache,
-						&error_handler_params, &hostid, 1, ZBX_MACRO_ENV_NONSECURE);
+				char	*error_resolve = NULL;
+
+				if (SUCCEED != zbx_dc_expand_user_and_func_macros_from_cache(um_handle->um_cache,
+						&error_handler_params, &hostid, 1, ZBX_MACRO_ENV_NONSECURE,
+						&error_resolve))
+				{
+					zabbix_log(LOG_LEVEL_DEBUG, "cannot resolve user macros: %s", error_resolve);
+					zbx_free(error_resolve);
+				}
 			}
 
 			if (ZBX_PREPROC_FAIL_SET_VALUE == step->error_handler)
