@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -15,6 +15,7 @@
 #include "zbxshmem.h"
 
 #include "zbxstr.h"
+#include "zbxnix.h"
 
 /******************************************************************************
  *                                                                            *
@@ -628,7 +629,7 @@ out:
  *               FAIL - otherwise                                             *
  *                                                                            *
  * Comments: When allocating shared memory with default zbx_shmem_create()    *
- *           function the available memory will be reduced by the allocator   *
+ *           function the available memory will reduced by the allocator      *
  *           overhead. This function estimates the overhead and requests      *
  *           enough memory so the available memory is greater or equal to the *
  *           requested size.                                                  *
@@ -637,11 +638,12 @@ out:
 int	zbx_shmem_create_min(zbx_shmem_info_t **info, zbx_uint64_t size, const char *descr, const char *param,
 		int allow_oom, char **error)
 {
-	void	*base = (void *)sizeof(zbx_shmem_info_t);
+	void	*base = NULL;
 
 	descr = ZBX_NULL2STR(descr);
 	param = ZBX_NULL2STR(param);
 
+	base = (void *)((zbx_shmem_info_t *)(base) + 1);
 	base = ALIGNPTR(base);
 	base = (void *)((void **)base + ZBX_SHMEM_BUCKET_COUNT);
 	base = (void *)((char *)base + strlen(descr) + 1);
