@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -18,6 +18,8 @@
 #include "zbxnix.h"
 #include "zbxstr.h"
 #include "zbxtime.h"
+#include "zbxmutexs.h"
+#include "zbxsysinfo.h"
 
 #ifdef ZBX_PROCSTAT_COLLECTOR
 
@@ -536,11 +538,6 @@ static void	procstat_free_query_data(zbx_procstat_query_data_t *data)
 	zbx_free(data);
 }
 
-static void	procstat_free_query_data_wrapper(void *data)
-{
-	procstat_free_query_data((zbx_procstat_query_data_t*)data);
-}
-
 /******************************************************************************
  *                                                                            *
  * Purpose: Tries to compress (remove inactive queries) the procstat shared   *
@@ -709,7 +706,7 @@ static void	procstat_get_monitored_pids(zbx_vector_uint64_t *pids, const zbx_vec
 	{
 		zbx_procstat_query_data_t	*qdata = (zbx_procstat_query_data_t *)queries->values[i];
 
-		if (SUCCEED != qdata->error || 0 == qdata->pids.values_num)
+		if (SUCCEED != qdata->error)
 			continue;
 
 		memcpy(pids->values + pids->values_num, qdata->pids.values,
@@ -1102,7 +1099,7 @@ clean:
 	zbx_proc_free_processes(&processes);
 	zbx_vector_ptr_destroy(&processes);
 
-	zbx_vector_ptr_clear_ext(&queries, procstat_free_query_data_wrapper);
+	zbx_vector_ptr_clear_ext(&queries, (zbx_mem_free_func_t)procstat_free_query_data);
 	zbx_vector_ptr_destroy(&queries);
 out:
 	runid++;
