@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -17,9 +17,14 @@
 
 #include "alias/alias.h"
 
-#include "zbxlog.h"
-#if !defined(_WINDOWS) && !defined(__MINGW32__)
-#include "zbxnix.h"
+#if !defined(WITH_AGENT2_METRICS)
+#	include "zbxthreads.h"
+#endif
+
+#if (!defined(_WINDOWS) && !defined(__MINGW32__)) && !defined(WITH_AGENT2_METRICS)
+#	include "zbxlog.h"
+#	include "zbxnix.h"
+#	include	"zbxfile.h"
 #endif
 
 #if defined(_WINDOWS) || defined(__MINGW32__)
@@ -32,8 +37,6 @@
 #include "zbxnum.h"
 #include "zbxparam.h"
 #include "zbxexpr.h"
-#include "zbxfile.h"
-#include "zbxthreads.h"
 #include "zbxtime.h"
 
 #ifdef WITH_AGENT_METRICS
@@ -1681,8 +1684,7 @@ static int	deserialize_agent_result(char *data, size_t data_offset, AGENT_RESULT
 	/* normally forked program should return data or error on abnormal termination, handle unexpected case */
 	if (data_offset < sizeof(int) + 1)
 	{
-		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Invalid data length:" ZBX_FS_SIZE_T,
-				(zbx_fs_size_t)data_offset));
+		SET_MSG_RESULT(result, zbx_dsprintf(NULL, "Invalid data length:" ZBX_FS_SIZE_T, data_offset));
 		return SYSINFO_RET_FAIL;
 	}
 
