@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -13,8 +13,13 @@
 **/
 
 #include "vmware_hv.h"
-#include "vmware_internal.h"
+
+#include "zbxcommon.h"
+
+#if defined(HAVE_LIBXML2) && defined(HAVE_LIBCURL)
+
 #include "zbxvmware.h"
+#include "vmware_internal.h"
 
 #include "vmware_ds.h"
 #include "vmware_vm.h"
@@ -29,8 +34,6 @@
 #	include <libxml/xpath.h>
 #endif
 
-#if defined(HAVE_LIBXML2) && defined(HAVE_LIBCURL)
-
 #define ZBX_HVPROPMAP_EXT(property, func, ver)								\
 	{property, ZBX_XPATH_PROP_OBJECT(ZBX_VMWARE_SOAP_HV) ZBX_XPATH_PROP_NAME_NODE(property), func, ver}
 #define ZBX_HVPROPMAP(property)			\
@@ -1333,7 +1336,6 @@ int	vmware_service_init_hv(zbx_vmware_service_t *service, CURL *easyhandle, cons
 		dsname = (zbx_vmware_dsname_t *)zbx_malloc(NULL, sizeof(zbx_vmware_dsname_t));
 		dsname->name = zbx_strdup(NULL, ds->name);
 		dsname->uuid = zbx_strdup(NULL, ds->uuid);
-		dsname->id = zbx_strdup(NULL, ds->id);
 		zbx_vector_vmware_hvdisk_create(&dsname->hvdisks);
 		zabbix_log(LOG_LEVEL_DEBUG, "%s(): for %d diskextents check multipath at ds:\"%s\"", __func__,
 				ds->diskextents.values_num, ds->name);
