@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -119,25 +119,23 @@ static const char	*help_message[] = {
 	"",
 	"      Log level control targets:",
 	"        process-type             All processes of specified type",
-	"                                 (availability manager, browser poller, configuration syncer,",
-	"                                 data sender, discovery manager, discovery worker, history syncer,",
-	"                                 housekeeper, http poller, icmp pinger, internal poller, ipmi manager,",
-	"                                 ipmi poller, java poller, odbc poller, poller, agent poller,",
-	"                                 http agent poller, snmp poller, preprocessing manager, preprocessing worker",
-	"                                 self-monitoring, snmp trapper, task manager, trapper, unreachable poller,",
-	"                                 vmware collector)",
+	"                                 (availability manager, configuration syncer, data sender, browser poller,",
+	"                                 discovery manager, history syncer, housekeeper, http poller,",
+	"                                 icmp pinger, ipmi manager, ipmi poller, java poller,",
+	"                                 odbc poller, poller, agent poller, http agent poller,",
+	"                                 snmp poller, preprocessing manager, self-monitoring, snmp trapper,",
+	"                                 task manager, trapper, unreachable poller, vmware collector)",
 	"        process-type,N           Process type and number (e.g., poller,3)",
 	"        pid                      Process identifier",
 	"",
 	"      Profiling control targets:",
 	"        process-type             All processes of specified type",
-	"                                 (availability manager, browser poller, configuration syncer,",
-	"                                 data sender, discovery manager, discovery worker, history syncer,",
-	"                                 housekeeper, http poller, icmp pinger, internal poller, ipmi manager,",
-	"                                 ipmi poller, java poller, odbc poller, poller, agent poller,",
-	"                                 http agent poller, snmp poller, preprocessing manager, preprocessing worker",
-	"                                 self-monitoring, snmp trapper, task manager, trapper, unreachable poller,",
-	"                                 vmware collector)",
+	"                                 (availability manager, configuration syncer, data sender, browser poller,",
+	"                                 discovery manager, history syncer, housekeeper, http poller,",
+	"                                 icmp pinger, ipmi manager, ipmi poller, java poller,",
+	"                                 odbc poller, poller, agent poller, http agent poller,",
+	"                                 snmp poller, preprocessing manager, self-monitoring, snmp trapper,",
+	"                                 task manager, trapper, unreachable poller, vmware collector)",
 	"        process-type,N           Process type and number (e.g., history syncer,1)",
 	"        pid                      Process identifier",
 	"        scope                    Profiling scope",
@@ -300,8 +298,7 @@ static char	*config_hostname_item		= NULL;
 static char	*zbx_config_snmptrap_file	= NULL;
 static char	*config_java_gateway		= NULL;
 static int	config_java_gateway_port	= ZBX_DEFAULT_GATEWAY_PORT;
-static char	*config_ssh_key_location	 = NULL;
-static int	config_log_slow_queries		= 0;	/* ms; 0 - disable */
+static char	*config_ssh_key_location	= NULL;
 static char	*config_load_module_path	= NULL;
 static char	**config_load_module		= NULL;
 static char	*config_user			= NULL;
@@ -315,7 +312,7 @@ static char	*config_ssl_key_location = NULL;
 static char	*config_webdriver_url = NULL;
 
 static zbx_config_tls_t		*zbx_config_tls = NULL;
-static zbx_config_dbhigh_t	*zbx_config_dbhigh = NULL;
+static zbx_db_config_t		*zbx_db_config = NULL;
 static zbx_config_vault_t	zbx_config_vault = {NULL, NULL, NULL, NULL, NULL, NULL, NULL};
 
 static char	*config_socket_path	= NULL;
@@ -539,8 +536,8 @@ static void	zbx_set_defaults(void)
 		zabbix_log(LOG_LEVEL_WARNING, "both Hostname and HostnameItem defined, using [%s]", config_hostname);
 	}
 
-	if (NULL == zbx_config_dbhigh->config_dbhost)
-		zbx_config_dbhigh->config_dbhost = zbx_strdup(zbx_config_dbhigh->config_dbhost, "localhost");
+	if (NULL == zbx_db_config->dbhost)
+		zbx_db_config->dbhost = zbx_strdup(zbx_db_config->dbhost, "localhost");
 
 	if (NULL == zbx_config_snmptrap_file)
 		zbx_config_snmptrap_file = zbx_strdup(zbx_config_snmptrap_file, "/tmp/zabbix_traps.tmp");
@@ -821,7 +818,7 @@ static void	zbx_validate_config(ZBX_TASK_EX *task)
 		}
 	}
 
-	err |= (FAIL == zbx_db_validate_config_features(zbx_program_type, zbx_config_dbhigh));
+	err |= (FAIL == zbx_db_config_validate_features(zbx_db_config, zbx_program_type));
 
 	if (0 != err)
 		exit(EXIT_FAILURE);
@@ -948,15 +945,15 @@ static void	zbx_load_config(ZBX_TASK_EX *task)
 				ZBX_CONF_PARM_OPT,	0,			1024},
 		{"ExternalScripts",		&config_externalscripts,		ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBHost",			&(zbx_config_dbhigh->config_dbhost),	ZBX_CFG_TYPE_STRING,
+		{"DBHost",			&(zbx_db_config->dbhost),	ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBName",			&(zbx_config_dbhigh->config_dbname),	ZBX_CFG_TYPE_STRING,
+		{"DBName",			&(zbx_db_config->dbname),	ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_MAND,	0,			0},
-		{"DBSchema",			&(zbx_config_dbhigh->config_dbschema),	ZBX_CFG_TYPE_STRING,
+		{"DBSchema",			&(zbx_db_config->dbschema),	ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBUser",			&(zbx_config_dbhigh->config_dbuser),	ZBX_CFG_TYPE_STRING,
+		{"DBUser",			&(zbx_db_config->dbuser),	ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBPassword",			&(zbx_config_dbhigh->config_dbpassword),
+		{"DBPassword",			&(zbx_db_config->dbpassword),
 											ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
 		{"VaultToken",			&zbx_config_vault.token,		ZBX_CFG_TYPE_STRING,
@@ -973,33 +970,33 @@ static void	zbx_load_config(ZBX_TASK_EX *task)
 				ZBX_CONF_PARM_OPT,	0,			0},
 		{"VaultDBPath",			&zbx_config_vault.db_path,		ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBSocket",			&(zbx_config_dbhigh->config_dbsocket),	ZBX_CFG_TYPE_STRING,
+		{"DBSocket",			&(zbx_db_config->dbsocket),	ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBPort",			&(zbx_config_dbhigh->config_dbport),	ZBX_CFG_TYPE_INT,
+		{"DBPort",			&(zbx_db_config->dbport),	ZBX_CFG_TYPE_INT,
 				ZBX_CONF_PARM_OPT,	1024,			65535},
 		{"AllowUnsupportedDBVersions",	&config_allow_unsupported_db_versions,	ZBX_CFG_TYPE_INT,
 				ZBX_CONF_PARM_OPT,	0,			1},
-		{"DBTLSConnect",		&(zbx_config_dbhigh->config_db_tls_connect),
+		{"DBTLSConnect",		&(zbx_db_config->db_tls_connect),
 											ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBTLSCertFile",		&(zbx_config_dbhigh->config_db_tls_cert_file),
+		{"DBTLSCertFile",		&(zbx_db_config->db_tls_cert_file),
 											ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBTLSKeyFile",		&(zbx_config_dbhigh->config_db_tls_key_file),
+		{"DBTLSKeyFile",		&(zbx_db_config->db_tls_key_file),
 											ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBTLSCAFile",			&(zbx_config_dbhigh->config_db_tls_ca_file),
+		{"DBTLSCAFile",			&(zbx_db_config->db_tls_ca_file),
 											ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBTLSCipher",			&(zbx_config_dbhigh->config_db_tls_cipher),
+		{"DBTLSCipher",			&(zbx_db_config->db_tls_cipher),
 											ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"DBTLSCipher13",		&(zbx_config_dbhigh->config_db_tls_cipher_13),
+		{"DBTLSCipher13",		&(zbx_db_config->db_tls_cipher_13),
 											ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
 		{"SSHKeyLocation",		&config_ssh_key_location,		ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
-		{"LogSlowQueries",		&config_log_slow_queries,		ZBX_CFG_TYPE_INT,
+		{"LogSlowQueries",		&(zbx_db_config->log_slow_queries),	ZBX_CFG_TYPE_INT,
 				ZBX_CONF_PARM_OPT,	0,			3600000},
 		{"LoadModulePath",		&config_load_module_path,		ZBX_CFG_TYPE_STRING,
 				ZBX_CONF_PARM_OPT,	0,			0},
@@ -1102,7 +1099,8 @@ static void	zbx_load_config(ZBX_TASK_EX *task)
 	/* initialize multistrings */
 	zbx_strarr_init(&config_load_module);
 
-	zbx_parse_cfg_file(config_file, cfg, ZBX_CFG_FILE_REQUIRED, ZBX_CFG_STRICT, ZBX_CFG_EXIT_FAILURE);
+	zbx_parse_cfg_file(config_file, cfg, ZBX_CFG_FILE_REQUIRED, ZBX_CFG_STRICT, ZBX_CFG_EXIT_FAILURE,
+			ZBX_CFG_ENVVAR_USE);
 
 	zbx_set_defaults();
 
@@ -1125,7 +1123,7 @@ static void	zbx_load_config(ZBX_TASK_EX *task)
 	}
 
 #if defined(HAVE_MYSQL) || defined(HAVE_POSTGRESQL)
-	zbx_db_validate_config(zbx_config_dbhigh);
+	zbx_db_config_validate(zbx_db_config);
 #endif
 #if defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
 	zbx_tls_validate_config(zbx_config_tls, config_forks[ZBX_PROCESS_TYPE_ACTIVE_CHECKS],
@@ -1203,7 +1201,7 @@ static void	zbx_on_exit(int ret, void *on_exit_args)
 	zbx_setproctitle_deinit();
 
 	zbx_config_tls_free(zbx_config_tls);
-	zbx_config_dbhigh_free(zbx_config_dbhigh);
+	zbx_db_config_free(zbx_db_config);
 
 	exit(EXIT_SUCCESS);
 }
@@ -1235,7 +1233,7 @@ int	main(int argc, char **argv)
 	argv = zbx_setproctitle_init(argc, argv);
 	zbx_progname = get_program_name(argv[0]);
 	zbx_config_tls = zbx_config_tls_new();
-	zbx_config_dbhigh = zbx_config_dbhigh_new();
+	zbx_db_config = zbx_db_config_create();
 
 	/* initialize libraries before using */
 	zbx_init_library_common(zbx_log_impl, get_zbx_progname, zbx_backtrace);
@@ -1248,7 +1246,7 @@ int	main(int argc, char **argv)
 			get_zbx_config_log_remote_commands, get_zbx_config_unsafe_user_parameters,
 			get_zbx_config_source_ip, NULL, NULL, NULL, NULL, NULL);
 	zbx_init_library_stats(get_zbx_program_type);
-	zbx_init_library_dbhigh(zbx_config_dbhigh);
+	zbx_init_library_db(zbx_db_config);
 	zbx_init_library_preproc(preproc_prepare_value_proxy, preproc_flush_value_proxy, get_zbx_progname);
 	zbx_init_library_eval(zbx_dc_get_expressions_by_name);
 
@@ -1371,17 +1369,14 @@ int	main(int argc, char **argv)
 			log_file_cfg.log_type, log_file_cfg.log_file_name, NULL, get_zbx_threads, get_zbx_threads_num);
 }
 
-static void	zbx_check_db(void)
+static int	zbx_check_db(void)
 {
 	struct zbx_db_version_info_t	db_version_info;
+	int				ret;
 
-	if (FAIL == zbx_db_check_version_info(&db_version_info, config_allow_unsupported_db_versions, zbx_program_type))
-	{
-		zbx_free(db_version_info.friendly_current_version);
-		exit(EXIT_FAILURE);
-	}
-
+	ret = zbx_db_check_version_info(&db_version_info, config_allow_unsupported_db_versions, zbx_program_type);
 	zbx_free(db_version_info.friendly_current_version);
+	return ret;
 }
 
 static void	proxy_db_init(void)
@@ -1389,9 +1384,7 @@ static void	proxy_db_init(void)
 	char		*error = NULL;
 	int		db_type, version_check;
 
-	zbx_config_dbhigh->read_only_recoverable = 1;
-
-	if (SUCCEED != zbx_db_init(zbx_dc_get_nextid, config_log_slow_queries, &error))
+	if (SUCCEED != zbx_db_init(&error))
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "cannot initialize database: %s", error);
 		zbx_free(error);
@@ -1404,18 +1397,19 @@ static void	proxy_db_init(void)
 	if (ZBX_DB_UNKNOWN == (db_type = zbx_db_get_database_type()))
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "cannot use database \"%s\": database is not a Zabbix database",
-				zbx_config_dbhigh->config_dbname);
+				zbx_db_config->dbname);
 		goto out;
 	}
 	else if (ZBX_DB_PROXY != db_type)
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "cannot use database \"%s\": Zabbix proxy cannot work with a"
-				" Zabbix server database", zbx_config_dbhigh->config_dbname);
+				" Zabbix server database", zbx_db_config->dbname);
 		goto out;
 	}
 
 	zbx_db_check_character_set();
-	zbx_check_db();
+	if (SUCCEED != zbx_check_db())
+		goto out;
 
 	if (SUCCEED != (version_check = zbx_db_check_version_and_upgrade(ZBX_HA_MODE_STANDALONE)))
 	{
@@ -1424,13 +1418,13 @@ static void	proxy_db_init(void)
 			goto out;
 
 		zbx_db_close();
-		zabbix_log(LOG_LEVEL_WARNING, "removing database file: \"%s\"", zbx_config_dbhigh->config_dbname);
+		zabbix_log(LOG_LEVEL_WARNING, "removing database file: \"%s\"", zbx_db_config->dbname);
 		zbx_db_deinit();
 
-		if (0 != unlink(zbx_config_dbhigh->config_dbname))
+		if (0 != unlink(zbx_db_config->dbname))
 		{
 			zabbix_log(LOG_LEVEL_CRIT, "cannot remove database file \"%s\": %s, exiting...",
-					zbx_config_dbhigh->config_dbname, zbx_strerror(errno));
+					zbx_db_config->dbname, zbx_strerror(errno));
 			exit(EXIT_FAILURE);
 		}
 
@@ -1442,11 +1436,6 @@ static void	proxy_db_init(void)
 		goto out;
 #endif
 	}
-
-#ifdef HAVE_ORACLE
-	zbx_db_table_prepare("items", NULL);
-	zbx_db_table_prepare("item_preproc", NULL);
-#endif
 	zbx_pb_init();
 	zbx_db_close();
 
@@ -1519,7 +1508,6 @@ int	MAIN_ZABBIX_ENTRY(int flags)
 								zbx_config_enable_remote_commands,
 								zbx_get_value_internal_ext_proxy,
 								config_ssh_key_location, config_webdriver_url,
-								.trapper_process_request_func_cb =
 								trapper_process_request_proxy,
 								zbx_autoreg_update_host_proxy};
 	zbx_thread_proxy_housekeeper_args	housekeeper_args = {zbx_config_timeout, config_housekeeping_frequency,
@@ -1632,11 +1620,6 @@ int	MAIN_ZABBIX_ENTRY(int flags)
 
 	zabbix_log(LOG_LEVEL_INFORMATION, "using configuration file: %s", config_file);
 
-#ifdef HAVE_ORACLE
-	zabbix_log(LOG_LEVEL_INFORMATION, "Support for Oracle DB is deprecated since Zabbix 7.0 and will be removed in "
-			"future versions");
-#endif
-
 #if defined(HAVE_GNUTLS) || defined(HAVE_OPENSSL)
 	if (SUCCEED != zbx_coredump_disable())
 	{
@@ -1715,8 +1698,8 @@ int	MAIN_ZABBIX_ENTRY(int flags)
 		exit(EXIT_FAILURE);
 	}
 
-	if (SUCCEED != zbx_vault_db_credentials_get(&zbx_config_vault, &zbx_config_dbhigh->config_dbuser,
-			&zbx_config_dbhigh->config_dbpassword, zbx_config_source_ip, config_ssl_ca_location,
+	if (SUCCEED != zbx_vault_db_credentials_get(&zbx_config_vault, &zbx_db_config->dbuser,
+			&zbx_db_config->dbpassword, zbx_config_source_ip, config_ssl_ca_location,
 			config_ssl_cert_location, config_ssl_key_location, &error))
 	{
 		zabbix_log(LOG_LEVEL_CRIT, "cannot initialize database credentials from vault: %s", error);
@@ -1731,8 +1714,8 @@ int	MAIN_ZABBIX_ENTRY(int flags)
 		zbx_free(error);
 		exit(EXIT_FAILURE);
 	}
-
 	proxy_db_init();
+
 	if (0 != config_forks[ZBX_PROCESS_TYPE_DISCOVERYMANAGER])
 		zbx_discoverer_init();
 
