@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -15,7 +15,6 @@
 #include "proxyconfigwrite.h"
 
 #include "zbxdbwrap.h"
-#include "zbxdbhigh.h"
 #include "zbxcommshigh.h"
 #include "zbxrtc.h"
 #include "zbx_host_constants.h"
@@ -82,12 +81,6 @@ static void	zbx_flags128_clear(zbx_flags128_t *flags, int bit)
 	flags->blocks[bit >> 6] &= ~(__UINT64_C(1) << (bit & 0x3f));
 }
 
-static void	zbx_flags128_or(zbx_flags128_t *flags, zbx_flags128_t *with)
-{
-	for (zbx_uint64_t i = 0; i < sizeof(flags->blocks) / sizeof(zbx_uint64_t); i++)
-		flags->blocks[i] |= with->blocks[i];
-}
-
 static void	zbx_flags128_init(zbx_flags128_t *flags)
 {
 	memset(flags->blocks, 0, sizeof(zbx_uint64_t) * (128 / 64));
@@ -142,10 +135,10 @@ typedef struct
 	const char			*rename_field;
 
 	/* To avoid self referencing foreign key conflicts when */
-	/* syncing rows the reset fields will be set to NULL for */
+	/* syncing rows the reset field will be set to NULL for */
 	/* all update and delete rows and marked for update.    */
-	/* As such only ID fields can be set as reset_fields.    */
-	zbx_vector_str_t		reset_fields;
+	/* As such only ID fields can be set as reset_field.    */
+	const char			*reset_field;
 
 	/* optional sql filter to limit managed object scope (exclude templates from hosts) */
 	char				*sql_filter;
@@ -160,7 +153,6 @@ static void	table_data_free(zbx_table_data_t *td)
 	zbx_vector_const_field_destroy(&td->fields);
 	zbx_vector_uint64_destroy(&td->del_ids);
 	zbx_vector_table_row_ptr_destroy(&td->updates);
-	zbx_vector_str_destroy(&td->reset_fields);
 	zbx_hashset_destroy(&td->rows);
 	zbx_free(td->sql_filter);
 	zbx_free(td);
@@ -319,8 +311,9 @@ static zbx_table_data_t	*proxyconfig_create_table(const char *name)
 
 	td->table = table;
 	td->rename_field = NULL;
+	td->reset_field = NULL;
 	td->sql_filter = NULL;
-	zbx_vector_str_create(&td->reset_fields);
+
 	zbx_vector_const_field_create(&td->fields);
 	zbx_hashset_create(&td->rows, 100, ZBX_DEFAULT_UINT64_HASH_FUNC, ZBX_DEFAULT_UINT64_COMPARE_FUNC);
 	zbx_vector_uint64_create(&td->del_ids);
@@ -354,8 +347,7 @@ static zbx_table_data_t	*proxyconfig_create_table(const char *name)
 	}
 	else if (0 == strcmp(table->table, "items"))
 	{
-		zbx_vector_str_append(&td->reset_fields, "master_itemid");
-		zbx_vector_str_append(&td->reset_fields, "interfaceid");
+		td->reset_field = "master_itemid";
 	}
 	else if (0 == strcmp(table->table, "proxy"))
 	{
@@ -363,7 +355,7 @@ static zbx_table_data_t	*proxyconfig_create_table(const char *name)
 	}
 	else if (0 == strcmp(table->table, "host_proxy"))
 	{
-		zbx_vector_str_append(&td->reset_fields, "proxyid");
+		td->reset_field = "proxyid";
 	}
 
 	/* get table fields from database schema */
@@ -494,8 +486,6 @@ static void	proxyconfig_add_default_tables(zbx_vector_table_data_ptr_t *config_t
 	}
 }
 
-#ifdef ZBX_DEBUG
-
 /******************************************************************************
  *                                                                            *
  * Purpose: dump table data object contents                                   *
@@ -557,7 +547,6 @@ static void	proxyconfig_dump_data(const zbx_vector_table_data_ptr_t *config_tabl
 	for (i = 0; i < config_tables->values_num; i++)
 		proxyconfig_dump_table(config_tables->values[i]);
 }
-#endif
 
 /******************************************************************************
  *                                                                            *
@@ -682,11 +671,10 @@ static int	proxyconfig_prepare_rows(zbx_table_data_t *td, char **error)
 {
 	char			*sql = NULL, delim = ' ';
 	size_t			sql_alloc = 0, sql_offset = 0;
-	int			i, ret, rename_index = -1;
+	int			i, ret, rename_index = -1, reset_index = -1;
 	zbx_vector_uint64_t	updateids;
-	zbx_flags128_t		reset_flags;
 
-	if (NULL == td->rename_field && 0 == td->reset_fields.values_num)
+	if (NULL == td->rename_field && NULL == td->reset_field)
 		return SUCCEED;
 
 	if (NULL != td->rename_field && -1 == (rename_index = table_data_get_field_index(td, td->rename_field)))
@@ -696,15 +684,12 @@ static int	proxyconfig_prepare_rows(zbx_table_data_t *td, char **error)
 		return FAIL;
 	}
 
-	memset (&reset_flags, 0, sizeof(reset_flags));
-	for (i = 0; i < td->reset_fields.values_num; i++)
+	if (NULL != td->reset_field)
 	{
-		int reset_index;
-
-		if (-1 == (reset_index = table_data_get_field_index(td, td->reset_fields.values[i])))
+		if (-1 == (reset_index = table_data_get_field_index(td, td->reset_field)))
 		{
-			*error = zbx_dsprintf(NULL, "unknown reset field \"%s\" for table \"%s\"",
-					td->reset_fields.values[i], td->table->table);
+			*error = zbx_dsprintf(NULL, "unknown reset field \"%s\" for table \"%s\"", td->reset_field,
+					td->table->table);
 			return FAIL;
 		}
 
@@ -713,7 +698,6 @@ static int	proxyconfig_prepare_rows(zbx_table_data_t *td, char **error)
 			*error = zbx_dsprintf(NULL, "only ID fields can be reset");
 			return FAIL;
 		}
-		zbx_flags128_set(&reset_flags, reset_index);
 	}
 
 	zbx_vector_uint64_create(&updateids);
@@ -728,10 +712,11 @@ static int	proxyconfig_prepare_rows(zbx_table_data_t *td, char **error)
 		if (-1 != rename_index)
 			zbx_flags128_set(&td->updates.values[i]->flags, rename_index);
 
-		zbx_flags128_or(&td->updates.values[i]->flags, &reset_flags);
+		if (-1 != reset_index)
+			zbx_flags128_set(&td->updates.values[i]->flags, reset_index);
 	}
 
-	if (0 != td->reset_fields.values_num)
+	if (-1 != reset_index)
 		zbx_vector_uint64_append_array(&updateids, td->del_ids.values, td->del_ids.values_num);
 
 	if (0 == updateids.values_num)
@@ -751,11 +736,8 @@ static int	proxyconfig_prepare_rows(zbx_table_data_t *td, char **error)
 		delim = ',';
 	}
 
-	for (i = 0; i < td->reset_fields.values_num; i++)
-	{
-		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%c%s=null", delim, td->reset_fields.values[i]);
-		delim = ',';
-	}
+	if (-1 != reset_index)
+		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%c%s=null", delim, td->reset_field);
 
 	zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, " where");
 	zbx_db_add_condition_alloc(&sql, &sql_alloc, &sql_offset, td->table->recid, updateids.values, updateids.values_num);
@@ -822,7 +804,6 @@ static int	proxyconfig_convert_value(const zbx_db_table_t *table, const zbx_db_f
 			break;
 		case ZBX_TYPE_CHAR:
 		case ZBX_TYPE_TEXT:
-		case ZBX_TYPE_SHORTTEXT:
 		case ZBX_TYPE_LONGTEXT:
 			if (NULL != value)
 				value_local.str = zbx_strdup(NULL, ZBX_NULL2EMPTY_STR(buf));
@@ -872,8 +853,6 @@ static int	proxyconfig_update_rows(zbx_table_data_t *td, char **error)
 
 	buf = (char *)zbx_malloc(NULL, buf_alloc);
 
-	zbx_db_begin_multiple_update(&sql, &sql_alloc, &sql_offset);
-
 	for (i = 0; i < td->updates.values_num; i++)
 	{
 		char		delim = ' ';
@@ -915,7 +894,6 @@ static int	proxyconfig_update_rows(zbx_table_data_t *td, char **error)
 					break;
 				case ZBX_TYPE_CHAR:
 				case ZBX_TYPE_TEXT:
-				case ZBX_TYPE_SHORTTEXT:
 				case ZBX_TYPE_LONGTEXT:
 					value_esc = zbx_db_dyn_escape_string_len(buf, field->length);
 					zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "'%s'", value_esc);
@@ -935,9 +913,7 @@ static int	proxyconfig_update_rows(zbx_table_data_t *td, char **error)
 			goto out;
 	}
 
-	zbx_db_end_multiple_update(&sql, &sql_alloc, &sql_offset);
-
-	if (16 < sql_offset && ZBX_DB_OK > zbx_db_execute("%s", sql))
+	if (ZBX_DB_OK > zbx_db_flush_overflowed_sql(sql, sql_offset))
 		goto out;
 
 	ret = SUCCEED;
@@ -964,21 +940,14 @@ out:
  ******************************************************************************/
 static int	proxyconfig_insert_rows(zbx_table_data_t *td, char **error)
 {
-	int				ret = SUCCEED;
+	int				ret = SUCCEED, reset_index = -1;
 	zbx_hashset_iter_t		iter;
 	zbx_vector_table_row_ptr_t	rows;
 	zbx_table_row_t			*row;
-	zbx_flags128_t			reset_flags;
 
-	zbx_flags128_init(&reset_flags);
-
-	for (int i = 0; i < td->reset_fields.values_num; i++)
-	{
-		int reset_index;
-
-		if (-1 != (reset_index = table_data_get_field_index(td, td->reset_fields.values[i])))
-			zbx_flags128_set(&reset_flags, reset_index);
-	}
+	/* invalid reset_index would have generated error during row preparation */
+	if (NULL != td->reset_field)
+		reset_index = table_data_get_field_index(td, td->reset_field);
 
 	zbx_vector_table_row_ptr_create(&rows);
 
@@ -1011,7 +980,6 @@ static int	proxyconfig_insert_rows(zbx_table_data_t *td, char **error)
 		{
 			const char	*pf = NULL;
 			zbx_json_type_t	type;
-			zbx_table_row_t	*update_row = NULL;
 
 			row = rows.values[i];
 
@@ -1020,7 +988,7 @@ static int	proxyconfig_insert_rows(zbx_table_data_t *td, char **error)
 			{
 				zbx_db_value_t	*value;
 
-				if (SUCCEED == zbx_flags128_isset(&reset_flags, j))
+				if (j == reset_index)
 				{
 					if (ZBX_TYPE_ID != fields[j]->type)
 					{
@@ -1041,7 +1009,7 @@ static int	proxyconfig_insert_rows(zbx_table_data_t *td, char **error)
 					/* so the correct ID will be updated later     */
 					zbx_flags128_set(&row->flags, PROXYCONFIG_ROW_EXISTS);
 					zbx_flags128_set(&row->flags, j);
-					update_row = row;
+					zbx_vector_table_row_ptr_append(&td->updates, row);
 
 					value = (zbx_db_value_t *)zbx_malloc(NULL, sizeof(zbx_db_value_t));
 					value->ui64 = 0;
@@ -1058,9 +1026,6 @@ static int	proxyconfig_insert_rows(zbx_table_data_t *td, char **error)
 				zbx_vector_db_value_ptr_append(&values, value);
 			}
 
-			if (NULL != update_row)
-				zbx_vector_table_row_ptr_append(&td->updates, update_row);
-
 			zbx_db_insert_add_values_dyn(&db_insert, values.values, values.values_num);
 clean:
 			for (j = 0; j < values.values_num; j++)
@@ -1069,7 +1034,6 @@ clean:
 				{
 					case ZBX_TYPE_CHAR:
 					case ZBX_TYPE_TEXT:
-					case ZBX_TYPE_SHORTTEXT:
 					case ZBX_TYPE_LONGTEXT:
 						zbx_free(values.values[j]->str);
 				}
@@ -1113,62 +1077,56 @@ clean:
 static void	proxyconfig_prepare_table(zbx_table_data_t *td, const char *key_field, zbx_vector_uint64_t *key_ids,
 		zbx_vector_uint64_t *recids)
 {
-	char		*sql = NULL, *buf;
-	size_t		sql_alloc = 0, buf_alloc = ZBX_KIBIBYTE;
-	int		batch_index = 0;
+	zbx_db_result_t	result;
+	zbx_db_row_t	dbrow;
+	char		*sql = NULL, *buf, *delim = " where";
+	size_t		sql_alloc = 0, sql_offset = 0, buf_alloc = ZBX_KIBIBYTE;
+	zbx_uint64_t	recid;
+	zbx_table_row_t	*row;
+	int		i;
 
 	if (NULL != key_ids && 0 == key_ids->values_num)
 		return;
 
 	buf = (char *)zbx_malloc(NULL, buf_alloc);
 
-	do
+	zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "select %s", td->table->recid);
+
+	for (i = 1; i < td->fields.values_num; i++)
+		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, ",%s", td->fields.values[i].field->name);
+
+	zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, " from %s", td->table->table);
+	if (NULL != key_ids)
 	{
-		char		*delim = " where";
-		zbx_db_result_t	result;
-		zbx_db_row_t	dbrow;
-		size_t		sql_offset = 0;
-
-		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "select %s", td->table->recid);
-
-		for (int i = 1; i < td->fields.values_num; i++)
-			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, ",%s", td->fields.values[i].field->name);
-
-		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, " from %s", td->table->table);
-		if (NULL != key_ids)
-		{
-			zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, delim);
-			add_batch_select_condition(&sql, &sql_alloc, &sql_offset, key_field, key_ids, &batch_index);
-			delim = " and";
-		}
-
-		if (NULL != td->sql_filter)
-			zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%s %s", delim, td->sql_filter);
-
-		result = zbx_db_select("%s", sql);
-
-		while (NULL != (dbrow = zbx_db_fetch(result)))
-		{
-			zbx_uint64_t	recid;
-			zbx_table_row_t	*row;
-
-			ZBX_STR2UINT64(recid, dbrow[0]);
-
-			if (NULL != recids)
-				zbx_vector_uint64_append(recids, recid);
-
-			if (NULL == (row = (zbx_table_row_t *)zbx_hashset_search(&td->rows, &recid)))
-			{
-				zbx_vector_uint64_append(&td->del_ids, recid);
-				continue;
-			}
-
-			if (SUCCEED != proxyconfig_compare_row(row, dbrow, &buf, &buf_alloc))
-				zbx_vector_table_row_ptr_append(&td->updates, row);
-		}
-		zbx_db_free_result(result);
+		zbx_strcpy_alloc(&sql, &sql_alloc, &sql_offset, delim);
+		zbx_db_add_condition_alloc(&sql, &sql_alloc, &sql_offset, key_field, key_ids->values, key_ids->values_num);
+		delim = " and";
 	}
-	while (NULL != key_ids && batch_index < key_ids->values_num);
+
+	if (NULL != td->sql_filter)
+		zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, "%s %s", delim, td->sql_filter);
+
+	zbx_snprintf_alloc(&sql, &sql_alloc, &sql_offset, " order by %s", td->table->recid);
+
+	result = zbx_db_select("%s", sql);
+
+	while (NULL != (dbrow = zbx_db_fetch(result)))
+	{
+		ZBX_STR2UINT64(recid, dbrow[0]);
+
+		if (NULL != recids)
+			zbx_vector_uint64_append(recids, recid);
+
+		if (NULL == (row = (zbx_table_row_t *)zbx_hashset_search(&td->rows, &recid)))
+		{
+			zbx_vector_uint64_append(&td->del_ids, recid);
+			continue;
+		}
+
+		if (SUCCEED != proxyconfig_compare_row(row, dbrow, &buf, &buf_alloc))
+			zbx_vector_table_row_ptr_append(&td->updates, row);
+	}
+	zbx_db_free_result(result);
 
 	zbx_free(sql);
 	zbx_free(buf);
@@ -1195,11 +1153,9 @@ static void	proxyconfig_prepare_table(zbx_table_data_t *td, const char *key_fiel
  *               FAIL    - otherwise                                          *
  *                                                                            *
  ******************************************************************************/
-static int	proxyconfig_sync_table(zbx_vector_table_data_ptr_t *config_tables, const char *table,
-		zbx_db_query_mask_t mask_queries, char **error)
+static int	proxyconfig_sync_table(zbx_vector_table_data_ptr_t *config_tables, const char *table, char **error)
 {
 	zbx_table_data_t	*td;
-	int			ret = SUCCEED;
 
 	if (NULL == (td = proxyconfig_get_table(config_tables, table)))
 		return SUCCEED;
@@ -1212,19 +1168,10 @@ static int	proxyconfig_sync_table(zbx_vector_table_data_ptr_t *config_tables, co
 	if (SUCCEED != proxyconfig_delete_rows(td, error))
 		return FAIL;
 
-	zbx_db_query_mask_t	old_queries = zbx_db_set_log_masked_values(mask_queries);
-
 	if (SUCCEED != proxyconfig_insert_rows(td, error))
-	{
-		ret = FAIL;
-		goto out;
-	}
+		return FAIL;
 
-	ret = proxyconfig_update_rows(td, error);
-out:
-	zbx_db_set_log_masked_values(old_queries);
-
-	return ret;
+	return proxyconfig_update_rows(td, error);
 }
 
 /******************************************************************************
@@ -1255,7 +1202,7 @@ static int	proxyconfig_sync_network_discovery(zbx_vector_table_data_ptr_t *confi
 			return FAIL;
 	}
 
-	if (SUCCEED != proxyconfig_sync_table(config_tables, "drules", ZBX_DB_DONT_MASK_QUERIES, error))
+	if (SUCCEED != proxyconfig_sync_table(config_tables, "drules", error))
 		return FAIL;
 
 	if (NULL == dchecks)
@@ -1295,7 +1242,7 @@ static int	proxyconfig_sync_regexps(zbx_vector_table_data_ptr_t *config_tables,
 			return FAIL;
 	}
 
-	if (SUCCEED != proxyconfig_sync_table(config_tables, "regexps", ZBX_DB_DONT_MASK_QUERIES, error))
+	if (SUCCEED != proxyconfig_sync_table(config_tables, "regexps", error))
 		return FAIL;
 
 	if (NULL == expressions)
@@ -1712,13 +1659,13 @@ static int	proxyconfig_sync_data(zbx_vector_table_data_ptr_t *config_tables, int
 
 	/* first sync isolated tables without relations to other tables */
 
-	if (SUCCEED != proxyconfig_sync_table(config_tables, "globalmacro", ZBX_DB_MASK_QUERIES, error))
+	if (SUCCEED != proxyconfig_sync_table(config_tables, "globalmacro", error))
 		return FAIL;
 
-	if (SUCCEED != proxyconfig_sync_table(config_tables, "config_autoreg_tls", ZBX_DB_DONT_MASK_QUERIES, error))
+	if (SUCCEED != proxyconfig_sync_table(config_tables, "config_autoreg_tls", error))
 		return FAIL;
 
-	if (SUCCEED != proxyconfig_sync_table(config_tables, "config", ZBX_DB_DONT_MASK_QUERIES, error))
+	if (SUCCEED != proxyconfig_sync_table(config_tables, "config", error))
 		return FAIL;
 
 	/* process related tables by scope */
@@ -1760,15 +1707,11 @@ static int	proxyconfig_sync_data(zbx_vector_table_data_ptr_t *config_tables, int
 		if (SUCCEED != proxyconfig_sync_templates(hosts_templates, hostmacro, error))
 			return FAIL;
 
-		zbx_db_query_mask_t	old_queries = zbx_db_set_log_masked_values(ZBX_DB_MASK_QUERIES);
-
 		if (SUCCEED != proxyconfig_insert_rows(hostmacro, error))
 			return FAIL;
 
 		if (SUCCEED != proxyconfig_update_rows(hostmacro, error))
 			return FAIL;
-
-		zbx_db_set_log_masked_values(old_queries);
 	}
 
 	zabbix_log(LOG_LEVEL_DEBUG, "End of %s()", __func__);
@@ -2005,7 +1948,7 @@ static int	proxyconfig_sync_proxy_group(zbx_vector_table_data_ptr_t *config_tabl
 	zbx_table_data_t	*host_proxy, *proxy;
 
 	if (NULL == (host_proxy = proxyconfig_get_table(config_tables, "host_proxy")))
-		return proxyconfig_sync_table(config_tables, "proxy", ZBX_DB_DONT_MASK_QUERIES, error);
+		return proxyconfig_sync_table(config_tables, "proxy", error);
 
 	if (NULL == (proxy = proxyconfig_get_table(config_tables, "proxy")))
 	{
@@ -2166,7 +2109,7 @@ int	zbx_proxyconfig_process(const char *addr, struct zbx_json_parse *jp, zbx_pro
 		loglevel = LOG_LEVEL_WARNING;
 
 	zabbix_log(loglevel, "received configuration data from server at \"%s\", datalen " ZBX_FS_SSIZE_T,
-			addr, (zbx_fs_ssize_t)(jp->end - jp->start + 1));
+			addr, jp->end - jp->start + 1);
 
 	if (1 == jp->end - jp->start)
 	{
@@ -2200,10 +2143,8 @@ int	zbx_proxyconfig_process(const char *addr, struct zbx_json_parse *jp, zbx_pro
 		if (SUCCEED != (ret = proxyconfig_parse_data(&jp_data, &config_tables, error)))
 			goto clean;
 
-#ifdef ZBX_DEBUG
 		if (SUCCEED == ZBX_CHECK_LOG_LEVEL(LOG_LEVEL_TRACE))
 			proxyconfig_dump_data(&config_tables);
-#endif
 
 		proxyconfig_add_default_tables(&config_tables);
 	}
