@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2026 Zabbix SIA
+** Copyright (C) 2001-2025 Zabbix SIA
 **
 ** This program is free software: you can redistribute it and/or modify it under the terms of
 ** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
@@ -24,7 +24,6 @@
 #include "zbxcacheconfig.h"
 #include "zbxdb.h"
 #include "zbxhistory.h"
-#include "zbxshmem.h"
 #include "zbxtime.h"
 #include "zbxtrends.h"
 #include "zbx_item_constants.h"
@@ -36,7 +35,6 @@
 #include "zbxstr.h"
 #include "zbxvariant.h"
 #include "zbxescalations.h"
-#include "zbxhash.h"
 
 /******************************************************************************
  *                                                                            *
@@ -59,7 +57,7 @@ static void	DBmass_update_trends(const ZBX_DC_TREND *trends, int trends_num,
 		qsort(trends_tmp, trends_num, sizeof(ZBX_DC_TREND), zbx_trend_compare);
 
 		while (0 < trends_num)
-			zbx_db_flush_trends(trends_tmp, &trends_num, trends_diff, ZBX_DC_SYNC_TREND_MODE_NORMAL);
+			zbx_db_flush_trends(trends_tmp, &trends_num, trends_diff);
 
 		zbx_free(trends_tmp);
 	}
@@ -593,7 +591,6 @@ static zbx_item_diff_t	*calculate_item_update(zbx_history_sync_item_t *item, con
 {
 	zbx_uint64_t	flags = 0;
 	const char	*item_error = NULL;
-	char		error_hash[ZBX_SHA512_BINARY_LENGTH];
 	zbx_item_diff_t	*diff;
 
 	if (0 != (ZBX_DC_FLAG_META & h->flags))
@@ -620,9 +617,7 @@ static zbx_item_diff_t	*calculate_item_update(zbx_history_sync_item_t *item, con
 						NULL, NULL, NULL, 0, 0, NULL, 0, NULL, 0, NULL, NULL, h->value.err);
 			}
 
-			zbx_sha512_hash(h->value.err, error_hash);
-
-			if (0 != memcmp(item->error_hash, error_hash, sizeof(error_hash)))
+			if (0 != strcmp(ZBX_NULL2EMPTY_STR(item->error), h->value.err))
 				item_error = h->value.err;
 		}
 		else
@@ -639,19 +634,14 @@ static zbx_item_diff_t	*calculate_item_update(zbx_history_sync_item_t *item, con
 			}
 
 			item_error = "";
-			zbx_sha512_hash(item_error, error_hash);
 		}
 	}
-	else if (ITEM_STATE_NOTSUPPORTED == h->state)
+	else if (ITEM_STATE_NOTSUPPORTED == h->state && 0 != strcmp(ZBX_NULL2EMPTY_STR(item->error), h->value.err))
 	{
-		zbx_sha512_hash(h->value.err, error_hash);
-		if (0 != memcmp(item->error_hash, error_hash, sizeof(item->error_hash)))
-		{
-			zabbix_log(LOG_LEVEL_WARNING, "error reason for \"%s:%s\" changed: %s", item->host.host,
-					item->key_orig, h->value.err);
+		zabbix_log(LOG_LEVEL_WARNING, "error reason for \"%s:%s\" changed: %s", item->host.host,
+				item->key_orig, h->value.err);
 
-			item_error = h->value.err;
-		}
+		item_error = h->value.err;
 	}
 
 	if (NULL != item_error)
@@ -677,10 +667,7 @@ static zbx_item_diff_t	*calculate_item_update(zbx_history_sync_item_t *item, con
 	}
 
 	if (0 != (ZBX_FLAGS_ITEM_DIFF_UPDATE_ERROR & flags))
-	{
 		diff->error = item_error;
-		memcpy(diff->error_hash, error_hash, sizeof(diff->error_hash));
-	}
 
 	return diff;
 }
@@ -935,14 +922,12 @@ static void	DCmass_prepare_history(zbx_dc_history_t *history, zbx_history_sync_i
 		{
 			if (SEC_PER_HOUR < (now - last_history_discard)) /* log once per hour */
 			{
-				zabbix_log(LOG_LEVEL_WARNING, "discarding history that is pointing to"
+				zabbix_log(LOG_LEVEL_TRACE, "discarding history that is pointing to"
 							" compressed history period");
 				last_history_discard = now;
 			}
 
-			zbx_dc_history_clean_value(h);
-			h->state = ITEM_STATE_NORMAL;
-			h->flags |= ZBX_DC_FLAG_NOVALUE;
+			h->flags |= ZBX_DC_FLAG_UNDEF;
 			continue;
 		}
 
@@ -966,14 +951,10 @@ static void	DCmass_prepare_history(zbx_dc_history_t *history, zbx_history_sync_i
 		}
 		else if (now - h->ts.sec > item->history_sec)
 		{
+			h->flags |= ZBX_DC_FLAG_NOHISTORY;
 			zabbix_log(LOG_LEVEL_WARNING, "item \"%s:%s\" value timestamp \"%s %s\" is outside history "
 					"storage period", item->host.host, item->key_orig,
 					zbx_date2str(h->ts.sec, NULL), zbx_time2str(h->ts.sec, NULL));
-
-			zbx_dc_history_clean_value(h);
-			h->state = ITEM_STATE_NORMAL;
-			h->flags |= ZBX_DC_FLAG_NOVALUE;
-			continue;
 		}
 
 		if (ITEM_VALUE_TYPE_FLOAT == item->value_type || ITEM_VALUE_TYPE_UINT64 == item->value_type)
@@ -984,14 +965,10 @@ static void	DCmass_prepare_history(zbx_dc_history_t *history, zbx_history_sync_i
 			}
 			else if (now - h->ts.sec > item->trends_sec)
 			{
+				h->flags |= ZBX_DC_FLAG_NOTRENDS;
 				zabbix_log(LOG_LEVEL_WARNING, "item \"%s:%s\" value timestamp \"%s %s\" is outside "
 						"trends storage period", item->host.host, item->key_orig,
 						zbx_date2str(h->ts.sec, NULL), zbx_time2str(h->ts.sec, NULL));
-
-				zbx_dc_history_clean_value(h);
-				h->state = ITEM_STATE_NORMAL;
-				h->flags |= ZBX_DC_FLAG_NOVALUE;
-				continue;
 			}
 		}
 		else
